# test r4ss installation
library(r4ss)
setwd('E:/ejdick/projects/~Vermilion 2020/SS_Vermilion_SoCA_STAR_Panel_Requests/current base model/c_same_as_b_but_reweighted_from_start')

# directories where models were run need to be defined
dir01 <- 'E:/ejdick/projects/~Vermilion 2020/SS_Vermilion_SoCA_STAR_Panel_Requests/current base model/b_Request 1, steepness estimated'
dir02 <- 'E:/ejdick/projects/~Vermilion 2020/SS_Vermilion_SoCA_STAR_Panel_Requests/current base model/c_same_as_b_but_reweighted_from_start'

plot.dir <- 'E:/ejdick/projects/~Vermilion 2020/SS_Vermilion_SoCA_STAR_Panel_Requests/current base model/c_same_as_b_but_reweighted_from_start'

# read two models
mod01 <- SS_output(dir=dir01) # 1 iteration of reweighting from pre-STAR base
mod02 <- SS_output(dir=dir02) # reweighted "from scratch" (all weights = 1)

# create list summarizing model results
mod.sum <- SSsummarize(list(mod01, mod02))

legend.labels <- c("one iter from pre-STAR base", "5 iterations from all weights=1")

# plot comparisons
SSplotComparisons(mod.sum, legendlabels=legend.labels, print=TRUE, plotdir=plot.dir)
# change legend location and/or number of columns
#SSplotComparisons(mod.sum, legendlabels=legend.labels, print=TRUE, plotdir=plot.dir, legendncol = 1, legendloc="topleft")

# make a table of likelihoods, estimated parameters, and derived quantities
# get parameters, excluding recdevs
# only include parameters that change across runs, exclude rec devs
parameters <- mod.sum$pars[mod.sum$pars$recdev==FALSE, c(mod.sum$n+1,1:mod.sum$n)]
parms.that.change <- parameters[apply(parameters[2:(mod.sum$n+1)], 1, function(x) length(unique(x))>1),]
# catchabilities are not estimated
parms.of.interest <- subset(parms.that.change, substr(Label, 1, 3) != "LnQ")
likelihood <- mod.sum$likelihoods[mod.sum$likelihoods$Label %in%
                                  c("TOTAL","Survey","Length_comp","Age_comp","Recruitment","Parm_priors"), c(mod.sum$n+1,1:mod.sum$n)]
# create row with number of estimated parameters per model (including rec devs)
npar.vec <- likelihood[1,] # use first row of likelihood to initialize object
npar.vec["Label"] <- "N.Parms"
npar.vec[1,2:(mod.sum$n+1)] <- mod.sum$npar
names(npar.vec) <- names(likelihood)
npar.vec

# get derived quantities
der.quants <- subset(mod.sum$quants, Label %in% c("SSB_unfished","Totbio_unfished","Bratio_2021","Recr_unfished","Dead_Catch_SPR","OFLCatch_2023"))
der.quants <- der.quants[, c(mod.sum$n+1,1:mod.sum$n)] # reorder columns
der.quants

model.comparison.table <- rbind(npar.vec, likelihood, parms.of.interest, der.quants)
row.names(model.comparison.table) <- 1:nrow(model.comparison.table)
names(model.comparison.table)[2:(mod.sum$n+1)] <- legend.labels
model.comparison.table
write.csv(model.comparison.table, "model_comparison_table.csv", row.names=FALSE)

